==> RT-Extension-ReplyWithMail-0.01.tar.gz: RT-Extension-ReplyWithMail-0.01/lib/RT/Extension/ReplyWithMail.pm <==
use strict;
use warnings;
package RT::Extension::ReplyWithMail;

our $VERSION = '0.01';

=head1 NAME

RT-Extension-ReplyWithMail - [One line description of module's purpose here]

=head1 DESCRIPTION

[Why would someone install this extension? What does it do? What problem
does it solve?]

=head1 RT VERSION

Works with RT [What versions of RT is this known to work with?]

[Make sure to use requires_rt and rt_too_new in Makefile.PL]

=head1 INSTALLATION

=over

=item C<perl Makefile.PL>

=item C<make>

=item C<make install>

May need root permissions

=item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>

Add this line:

    Plugin('RT::Extension::ReplyWithMail');

=item Clear your mason cache

    rm -rf /opt/rt4/var/mason_data/obj

=item Restart your webserver

=back

=head1 AUTHOR

Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>

=for html <p>All bugs should be reported via email to <a
href="mailto:bug-RT-Extension-ReplyWithMail@rt.cpan.org">bug-RT-Extension-ReplyWithMail@rt.cpan.org</a>
or via the web at <a
href="http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ReplyWithMail">rt.cpan.org</a>.</p>

=for text
    All bugs should be reported via email to
        bug-RT-Extension-ReplyWithMail@rt.cpan.org
    or via the web at
        http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ReplyWithMail

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2021 by Averkios

This is free software, licensed under:

  The GNU General Public License, Version 2, June 1991

=cut

1;

==> RT-Extension-ReplyWithMail-0.02.tar.gz: RT-Extension-ReplyWithMail-0.02/lib/RT/Extension/ReplyWithMail.pm <==
use strict;
use warnings;
package RT::Extension::ReplyWithMail;

our $VERSION = '0.02';

=head1 NAME

RT-Extension-ReplyWithMail - Reply to the ticker using your default mail client

=head1 DESCRIPTION

This extension adds an extra action in your actions menu, named "ReplyWithMail". This action uses the mailto: HTML tag to generate a base mail structure, so that you can reply using your native email client instead of RT's WebUI

=head1 RT VERSION

Works with RT 5.0.2

=head1 INSTALLATION

=over

=item C<perl Makefile.PL>

=item C<make>

=item C<make install>

May need root permissions

=item Edit your F</opt/rt5/etc/RT_SiteConfig.pm>

Add this line:

    Plugin('RT::Extension::ReplyWithMail');

=item Clear your mason cache

    rm -rf /opt/rt5/var/mason_data/obj

=item Restart your webserver

=back

=head1 AUTHOR

Averkios

=for html <p>All bugs should be reported via email to <a
href="mailto:bug-RT-Extension-ReplyWithMail@rt.cpan.org">bug-RT-Extension-ReplyWithMail@rt.cpan.org</a>
or via the web at <a
href="http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ReplyWithMail">rt.cpan.org</a>.</p>

=for text
    All bugs should be reported via email to
        bug-RT-Extension-ReplyWithMail@rt.cpan.org
    or via the web at
        http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ReplyWithMail

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2021 by Averkios

This is free software, licensed under:

  The GNU General Public License, Version 2, June 1991

=cut

1;
